@@ -1,4 +1,4 @@
-#!/opt/local/bin/perl
+#!/usr/bin/perl
 use utf8;
 binmode stdin,":utf8";
 binmode stdout,":utf8";
@@ -7,6 +7,12 @@ while (<>) {
 s/لله/LLh/g;
 s/لِله/LiLh/g;
 s/لِّله/L+iLh/g;
+s/أ/'a/g;
+s/إ/'i/g;
+s/ؤ/'u/g;
+s/ىٔ/'I/g;
+s/هٔ/e/g;
+s/آ/'A/g;
 s/ء/|/g;
 s/ٱ/A*/g;
 s/آ/'A/g;
@@ -64,6 +70,10 @@ s/ّ/+/g;
 s/ْ/o/g;
 s/ٰ/a*/g;
 s/ٓ/a**/g;
+s/،/,/g;
+s/؟/?/g;
+s/؛/;/g;
+tr/٠١٢٣٤٥٦٧٨٩٪/0123456789%/;
 s/‍/-/g;
 s/ـ/--/g;
 s/([tds])h/\1-h/g;
